@@ -27,6 +27,8 @@ from vortex.PayloadEnvelope import PayloadEnvelope, VortexMsgList
 from vortex.PayloadPriority import DEFAULT_PRIORITY
 from vortex.VortexABC import VortexABC, VortexInfo
 from vortex.VortexPayloadProtocol import VortexPayloadProtocol
+from vortex.VortexServer import HEART_BEAT_PERIOD
+from vortex.VortexUtil import logLargeMessages
 
 logger = logging.getLogger(name=__name__)
 
@@ -130,7 +132,7 @@ class VortexClientHttp(VortexABC):
             raise Exception("Reconnecting is not implemented")
 
         self._beat()
-        self._beatLoopingCall.start(5.0)
+        self._beatLoopingCall.start(HEART_BEAT_PERIOD)
 
         deferred = Deferred()
 
@@ -178,6 +180,8 @@ class VortexClientHttp(VortexABC):
         if not isinstance(vortexMsgs, list):
             vortexMsgs = [vortexMsgs]
 
+        logLargeMessages(logger, vortexMsgs, self._serverVortexUuid)
+
         # Check if the vortexUuid matches the destination uuid
         #
         # if vortexUuid and vortexUuid != self._
