@@ -1,7 +1,10 @@
 import logging
 from copy import copy
+from datetime import datetime
 
+import pytz
 from twisted.internet import reactor
+from twisted.internet.defer import DeferredSemaphore
 from twisted.internet.defer import TimeoutError, inlineCallbacks
 from twisted.python.failure import Failure
 
@@ -11,6 +14,7 @@ from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.PayloadResponse import PayloadResponse
 from vortex.TupleSelector import TupleSelector
 from vortex.VortexABC import SendVortexMsgResponseCallable
+from vortex.VortexFactory import NoVortexException
 from vortex.VortexFactory import VortexFactory
 from vortex.handler.TupleDataObservableCache import TupleDataObservableCache
 from vortex.handler.TupleDataObservableHandler import (
@@ -24,6 +28,11 @@ logger = logging.getLogger(__name__)
 class TupleDataObservableProxyHandler(TupleDataObservableCache):
     __CHECK_PERIOD = 30  # seconds
 
+    # To avoid saturating the CPU, we will prepare only 10 responses at a time.
+    # Once the responses are prepared,
+    #  they will be queued in the VortexPushProducer
+    _prepareResponsesSemaphore = DeferredSemaphore(10)
+
     def __init__(
         self,
         observableName,
@@ -61,7 +70,9 @@ class TupleDataObservableProxyHandler(TupleDataObservableCache):
         self._localObservableHandler.shutdown()
 
         # Finally, Setup our endpoint
-        self._endpoint = PayloadEndpoint(self._filt, self._process)
+        self._endpoint = PayloadEndpoint(
+            self._filt, self._processBeforeSemaphore
+        )
 
         TupleDataObservableCache.start(self)
 
@@ -101,6 +112,46 @@ class TupleDataObservableProxyHandler(TupleDataObservableCache):
 
     ## ----- Implement proxy from here on in
 
+    def _processBeforeSemaphore(self, *args, **kwargs):
+        d = self._prepareResponsesSemaphore.run(
+            self._processAfterSemaphore, datetime.now(pytz.utc), *args, **kwargs
+        )
+        d.addErrback(vortexLogFailure, logger, consumeError=True)
+
+    @inlineCallbacks
+    def _processAfterSemaphore(
+        self,
+        queuedTime: datetime,
+        payloadEnvelope: PayloadEnvelope,
+        *args,
+        **kwargs,
+    ):
+        deltaTime = datetime.now(pytz.utc) - queuedTime
+        queueSize = len(self._prepareResponsesSemaphore.waiting)
+
+        def logIt(logFunc):
+            logFunc(
+                "_process call was queued for %s, queue size " "%s",
+                deltaTime,
+                queueSize,
+            )
+
+        if 15.0 < deltaTime.total_seconds() or 2000 < queueSize:
+            logIt(logger.warning)
+
+        elif 5.0 < deltaTime.total_seconds() or 200 < queueSize:
+            logIt(logger.debug)
+
+        startTime = datetime.now(pytz.utc)
+        yield self._process(payloadEnvelope, *args, **kwargs)
+        processingTime = datetime.now(pytz.utc) - startTime
+        if 5.0 < processingTime.total_seconds():
+            logger.debug(
+                "Payload endpoint took %s\npayload.filt=%s",
+                processingTime,
+                payloadEnvelope.filt,
+            )
+
     @inlineCallbacks
     def _process(
         self,
@@ -108,8 +159,11 @@ class TupleDataObservableProxyHandler(TupleDataObservableCache):
         vortexUuid: str,
         vortexName: str,
         sendResponse: SendVortexMsgResponseCallable,
-        **kwargs
+        **kwargs,
     ):
+        if not VortexFactory.isVortexUuidOnline(vortexUuid):
+            return
+
         if vortexName == self._proxyToVortexName:
             yield self._processUpdateFromBackend(payloadEnvelope)
 
@@ -313,4 +367,12 @@ class TupleDataObservableProxyHandler(TupleDataObservableCache):
         d = VortexFactory.sendVortexMsg(
             vortexMsgs=vortexMsg, destVortexUuid=destVortexUuid
         )
-        d.addErrback(vortexLogFailure, logger, consumeError=True)
+        d.addErrback(self._sendErrback)
+
+    def _sendErrback(self, failure):
+
+        if failure.check(NoVortexException):
+            self._logger.debug(str(failure.value))
+            return
+
+        vortexLogFailure(failure, self._logger)
